Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(198)

Unified Diff: media/filters/decoder_selector.h

Issue 1423163004: media: Replace DecryptorReadyCB with CdmReadyCB. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: comments addressed Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/filters/audio_decoder_selector_unittest.cc ('k') | media/filters/decoder_selector.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/filters/decoder_selector.h
diff --git a/media/filters/decoder_selector.h b/media/filters/decoder_selector.h
index 6db6061ae74f9092b273da5d957ed6be2637cc48..c8a8ff95a7a63e2fce5d634abf2f3ad71cd8d7d0 100644
--- a/media/filters/decoder_selector.h
+++ b/media/filters/decoder_selector.h
@@ -9,7 +9,7 @@
#include "base/memory/ref_counted.h"
#include "base/memory/scoped_vector.h"
#include "base/memory/weak_ptr.h"
-#include "media/base/decryptor.h"
+#include "media/base/cdm_context.h"
#include "media/base/demuxer_stream.h"
#include "media/base/pipeline_status.h"
#include "media/filters/decoder_stream_traits.h"
@@ -22,7 +22,6 @@ namespace media {
class DecoderBuffer;
class DecryptingDemuxerStream;
-class Decryptor;
class MediaLog;
// DecoderSelector (creates if necessary and) initializes the proper
@@ -67,10 +66,10 @@ class MEDIA_EXPORT DecoderSelector {
// 1. This must not be called again before |select_decoder_cb| is run.
// 2. Decoders that fail to initialize will be deleted. Future calls will
// select from the decoders following the decoder that was last returned.
// 3. |set_decryptor_ready_cb| is optional. If |set_decryptor_ready_cb| is
// null, no decryptor will be available to perform decryption.
void SelectDecoder(DemuxerStream* stream,
- const SetDecryptorReadyCB& set_decryptor_ready_cb,
+ const SetCdmReadyCB& set_cdm_ready_cb,
const SelectDecoderCB& select_decoder_cb,
const typename Decoder::OutputCB& output_cb,
const base::Closure& waiting_for_decryption_key_cb);
@@ -91,7 +90,7 @@ class MEDIA_EXPORT DecoderSelector {
scoped_refptr<MediaLog> media_log_;
DemuxerStream* input_stream_;
- SetDecryptorReadyCB set_decryptor_ready_cb_;
+ SetCdmReadyCB set_cdm_ready_cb_;
SelectDecoderCB select_decoder_cb_;
typename Decoder::OutputCB output_cb_;
base::Closure waiting_for_decryption_key_cb_;
@@ -67,10 +66,10 @@ class MEDIA_EXPORT DecoderSelector {
// 2. Decoders that fail to initialize will be deleted. Future calls will
// select from the decoders following the decoder that was last returned.
- // 3. |set_decryptor_ready_cb| is optional. If |set_decryptor_ready_cb| is
- // null, no decryptor will be available to perform decryption.
+ // 3. |set_cdm_ready_cb| is optional. If |set_cdm_ready_cb| is
+ // null, no CDM will be available to perform decryption.
void SelectDecoder(DemuxerStream* stream,
« no previous file with comments | « media/filters/audio_decoder_selector_unittest.cc ('k') | media/filters/decoder_selector.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698